@@ -2,9 +2,6 @@
 
 library(RVowpalWabbit)
 
-## change to 'test' directory of package
-setwd( system.file("test", package="RVowpalWabbit") )
-
 # Test 5: add -q .., adaptive, and more (same input, different outputs)
 # {VW} --initial_t 1 --power_t 0.5 --adaptive -q Tf -q ff -f models/0002a.model train-sets/0002.dat
 test5 <- c("--initial_t", "1",
@@ -12,8 +9,8 @@ test5 <- c("--initial_t", "1",
            "--adaptive",
            "-q", "Tf",
            "-q", "ff",
-           "-f", "models/0002a.model",
-           "train-sets/0002.dat")
+           "-f", system.file("test", "models", "0002a.model", package="RVowpalWabbit"),
+           system.file("test", "train-sets", "0002.dat", package="RVowpalWabbit"))
 
 res <- vw(test5, quiet=FALSE)
 print(res)
