@@ -2,15 +2,11 @@
 
 library(RVowpalWabbit)
 
-## change to 'test' directory of package
-setwd( system.file("test", package="RVowpalWabbit") )
-
-
 # Test 7: using -q and multiple threads
 # {VW} --adaptive -q ff -f models/0002c.model train-sets/0002.dat
 test7 <- c("--adaptive", "-q", "ff",
-           "-f", "models/0002c.model",
-           "train-sets/0002.dat")
+           "-f", system.file("test", "models", "0002c.model", package="RVowpalWabbit"),
+           system.file("test", "train-sets", "0002.dat", package="RVowpalWabbit"))
 
 res <- vw(test7, quiet=FALSE)
 print(res)
