@@ -2,15 +2,11 @@
 
 library(RVowpalWabbit)
 
-## change to 'test' directory of package
-setwd( system.file("test", package="RVowpalWabbit") )
-
-
 ## Test 8: predicts on test 7 model
 ## {VW} -t -i models/0002c.model -d train-sets/0002.dat -p 0002c.predict
 test8 <- c("-t",
-           "-i", "models/0002c.model",
-           "-d", "train-sets/0002.dat",
+           "-i", system.file("test", "models", "0002c.model", package="RVowpalWabbit"),
+           "-d", system.file("test", "train-sets", "0002.dat", package="RVowpalWabbit"),
            "-p", file.path(tempdir(), "0002c.predict.tmp"))
 
 res <- vw(test8, quiet=FALSE)
